/***************************************************************************//**
 *   @file   Main.c
 *   @brief  Implementation of the program's main function.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 365
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRX62N.h"
#include "ST7579.h"
#include "ADXL345.h"

/******************************************************************************/
/* Variables Declarations                                                     */
/******************************************************************************/
const unsigned char adiLogo [2 * 19] =
	{ 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x07, 0x07,
	  0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7F, 0x7F,
	  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xC0,
	  0xC0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF8, 0xF8, 0xFC,
	  0xFC, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF };	// ADI Logo.
unsigned char 	periodEnd	= 0;	// Indicates when the OneShot period ends.
unsigned short	x			= 0;	// X-axis's output data.
unsigned short	y			= 0;	// Y-axis's output data.
unsigned short	z 			= 0;	// Z-axis's output data.
unsigned char	intSource	= 0;	// Value of the ADXL345_INT_SOURCE register.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
void DelaySeconds(float seconds);
void OneShotCallback(void);

/***************************************************************************//**
 * @brief Main function.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void main(void)
{
	YRDKRX62N_Init();
	ST7579_Init();
    ST7579_Image(2,0,adiLogo,19,16);
    ST7579_String(2,21,"ANALOG");
    ST7579_String(3,21,"DEVICES");
    ST7579_String(4,0,"wiki.analog.com");
	DelaySeconds(2);
	ST7579_Clear();
	ST7579_Image(0,0,adiLogo,19,16);	
	ST7579_String(0,22,"ST7579 OK");
	if(ADXL345_Init())
	{
		ST7579_String(1,22,"ADXL345 OK");
	}
	else
	{
		ST7579_String(2,22,"ADXL345 Err");
	}
	ADXL345_SetTapDetection(ADXL345_SINGLE_TAP |
							ADXL345_DOUBLE_TAP,	// Tap type.
							ADXL345_TAP_X_EN,	// Axis control.
							0x10,				// Tap duration.
							0x10,				// Tap latency.
							0x40,				// Tap window. 
							0x10,				// Tap threshold.
							0x00);				// Interrupt Pin.
	ADXL345_SetFreeFallDetection(0x01,	// Free-fall detection enabled.
								 0x05,	// Free-fall threshold.
								 0x14,	// Time value for free-fall detection.
								 0x00);	// Interrupt Pin.
	ADXL345_SetPowerMode(0x1);			// Measure mode.
	while(1)
	{
		ADXL345_GetXyz(&x,&y,&z);
		ST7579_String(2,6,"X data:");
		ST7579_Number(2,84,x);
		ST7579_String(3,6,"Y data:");
		ST7579_Number(3,84,y);
		ST7579_String(4,6,"Z data:");
		ST7579_Number(4,84,z);
		intSource = ADXL345_GetRegisterValue(ADXL345_INT_SOURCE);
		if((intSource & ADXL345_SINGLE_TAP) != 0)
		{
			ST7579_String(5,0,"Single Tap");
		}
		if((intSource & ADXL345_DOUBLE_TAP) != 0)
		{
			ST7579_String(6,0,"Double Tap");
		}
		if((intSource & ADXL345_FREE_FALL) != 0)
		{
			ST7579_String(7,0,"Free-Fall");
		}
	}
}

/***************************************************************************//**
 * @brief Creates a delay of seconds.
 *
 * @param seconds - time in seconds.
 *
 * @return None.
*******************************************************************************/
void DelaySeconds(float seconds)
{
	periodEnd = 0;
	R_TMR_CreateOneShot(PDL_TMR_UNIT0,
						PDL_TMR_OUTPUT_OFF,
						seconds,
						OneShotCallback,
						4);
	while(periodEnd == 0);
}

/***************************************************************************//**
 * @brief OneShot callback function.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void OneShotCallback(void)
{
	periodEnd = 1;
}
